@@ -17,13 +17,17 @@ def run_command(command):
 def run_mq_command(mq_command):
     """Run an MQ command in a shell script with the MQ environment set up."""
     with tempfile.NamedTemporaryFile(delete=False, mode='w', suffix='.sh') as script_file:
-        script_file.write(f"""
+        script_content = f"""
         #!/bin/bash
         . /opt/mqm/bin/setmqenv -s
+        export MQSERVER='DEV.APP.SVRCONN/TCP/localhost(1414)'
+        export MQSAMP_USER_ID='app'
         {mq_command}
-        """)
+        """
+        script_file.write(script_content)
         script_file_path = script_file.name
     os.chmod(script_file_path, 0o755)
+    print(f"Running script:\n{script_content}")  # Debugging information
     try:
         output = run_command(f"/bin/bash {script_file_path}")
     finally:
@@ -68,8 +72,8 @@ def stop_queue_manager(args):
 
 def extract_queue_names(output):
     """Extract queue names from the DISPLAY QUEUE output."""
-    queue_name_pattern = re.compile(r"\s*QUEUE\(([^)]+)\)")
-    return queue_name_pattern.findall(output)
+    queue_name_pattern = re.compile(r"^\s*QUEUE\(([^)]+)\)", re.MULTILINE)
+    return [name for name in queue_name_pattern.findall(output) if name != '*']
 
 def display_queues(args):
     """Display all queues in the specified queue manager."""
@@ -89,13 +93,29 @@ def get_queue_permissions(args):
     queue_names = extract_queue_names(queues_output)
 
     for queue_name in queue_names:
-        command = f'/opt/mqm/bin/dspmqaut -m {queue_manager} -t q -n "{queue_name}" -p {user}'
         try:
+            command = f'/opt/mqm/bin/dspmqaut -m {queue_manager} -t q -n "{queue_name}" -p {user}'
             permissions_output = run_command(command)
             print(f"Permissions for queue '{queue_name}':\n{permissions_output}\n")
         except RuntimeError as e:
             print(f"Error fetching permissions for queue '{queue_name}': {e}")
 
+def put_message(args):
+    """Put a message on a queue in the specified queue manager."""
+    with tempfile.NamedTemporaryFile(delete=False, mode='w') as msg_file:
+        msg_file.write(args.message)
+        msg_file_path = msg_file.name
+    command = f'cat {msg_file_path} | /opt/mqm/samp/bin/amqsputc {args.queue_name} {args.qm_name}'
+    output = run_mq_command(command)
+    print(f"Message put on queue {args.queue_name} in queue manager {args.qm_name}.\n{output}")
+    os.remove(msg_file_path)
+
+def get_message(args):
+    """Get a message from a queue in the specified queue manager."""
+    command = f'/opt/mqm/samp/bin/amqsgetc {args.queue_name} {args.qm_name}'
+    output = run_mq_command(command)
+    print(f"Message retrieved from queue {args.queue_name} in queue manager {args.qm_name}.\n{output}")
+
 def main():
     parser = argparse.ArgumentParser(description="IBM MQ Management CLI")
     subparsers = parser.add_subparsers(
@@ -180,6 +200,29 @@ def main():
     ibm-mq-cli get_permissions MyQueueManager anotheruser
     """
 
+    # Subparser for putting a message on a queue
+    parser_put_message = subparsers.add_parser("put_message", help="Put a message on a queue")
+    parser_put_message.add_argument("qm_name", help="Name of the queue manager")
+    parser_put_message.add_argument("queue_name", help="Name of the queue")
+    parser_put_message.add_argument("message", help="Message to put on the queue")
+    parser_put_message.set_defaults(func=put_message)
+    parser_put_message.epilog = """
+    Example usage:
+    ibm-mq-cli put_message QM1 DEV.QUEUE.1 "Hello, World!"
+    ibm-mq-cli put_message MyQueueManager MyQueue "Test Message"
+    """
+
+    # Subparser for getting a message from a queue
+    parser_get_message = subparsers.add_parser("get_message", help="Get a message from a queue")
+    parser_get_message.add_argument("qm_name", help="Name of the queue manager")
+    parser_get_message.add_argument("queue_name", help="Name of the queue")
+    parser_get_message.set_defaults(func=get_message)
+    parser_get_message.epilog = """
+    Example usage:
+    ibm-mq-cli get_message QM1 DEV.QUEUE.1
+    ibm-mq-cli get_message MyQueueManager MyQueue
+    """
+
     args = parser.parse_args()
     if hasattr(args, "func"):
         args.func(args)
